#!/bin/sh
# Open a n new terminals in the current working directory.
# (this is not 'thread safe' at all)
# Usage: spawn.sh [n] [w|t]
# Files: ~/.spawn, adds a line to ~/.profile (once) when creating ~/.spawn.
# @version 2007 Oct 27 (Updated to use a tmp file / AppleScript, for Leopard)
# @author Mark Fickett [ naib.webhop.org ]

# Check argument validity
NUMBER=1
DESCR=windows
KEYSTROKE=n
for arg in $*
do
	if [ $arg = "t" ]
	then
		KEYSTROKE=t
		DESCR=tabs
	elif [ $arg = "w" ]
	then
		KEYSTROKE=n
		DESCR=windows
	else
		let NUM=$arg
		if [ $NUM = $arg  -a $NUM -gt 0 ]
		then
			NUMBER=$NUM
		else
			echo bad number $arg or unrecognized option
			echo Usage: $0 [n] [wt]
			echo n = number of new windows/tabs
			echo w = open new windows
			echo t = open new tabs
			exit 1;
		fi
	fi
done

# Advisory
echo spawning $NUMBER new Terminal $DESCR in $PWD

# Temporary file: contain the 'cd' command
if [ ! -f ~/.spawn ]
then
	echo ". ~/.spawn" >> ~/.profile
fi
echo cd \"$PWD\" > ~/.spawn

# Open new windows
while [ $NUMBER -gt 0 ]
do
	osascript -e "tell application \"System Events\"" \
		-e "tell application \"Terminal\" to activate" \
		-e "keystroke \"$KEYSTROKE\" using command down" \
		-e "end tell"
	let NUMBER=$NUMBER-1
done

sleep .3 # protect against changing it back before the new Terminal opens
echo "" > ~/.spawn

exit 0;
